DnsResolver

Struct DnsResolver 

pub struct DnsResolver<R>
where R: Runtime,
{ /* private fields */ }
Available on crate features resolver and dns only.
A resolver which supports both domain:port and socket address.

N.B. If a domain contains multiple ip addresses, there is no guarantee that which one will be used. Users should make sure that the domain only contains one ip address, to make sure that DnsResolver can work properly.

e.g. valid address format:

  1. www.example.com:8080 // domain
  2. [::1]:8080 // ipv6
  3. 127.0.0.1:8080 // ipv4