Module types

Module types 

The types used in serf.

Modules

bytes
Provides abstractions for working with bytes.
coordinate
Vivialdi coordinate implementation
utils
Utils for protobuf-like encoding/decoding

Macros

format_smolstr
Formats arguments to a SmolStr, potentially without allocating.

Structs

InvalidKeyLength
Parse error for SecretKey from bytes slice
KeyRequestMessage
KeyRequest is used to contain input parameters which get broadcasted to all nodes as part of a key query operation.
KeyRequestOptions
KeyRequestOptions is used to contain optional parameters for a keyring operation
KeyResponse
KeyResponse is used to relay a query for a list of all keys in use.
KeyResponseMessage
Key response message
KeyResponseMessageRef
The reference type for KeyResponseMessage.
LamportClock
A thread safe implementation of a lamport clock. It uses efficient atomic operations for all of its functions, falling back to a heavy lock only if there are enough CAS failures.
LamportTime
A lamport time is a simple u64 that represents a point in time.
Member
A single member of the Serf cluster.
MemberRef
A reference type to Member
Node
Node is consist of id and address, which can be used as a identifier in a distributed system.
NodeId
A unique string identifying a server for all time. The maximum length of an id is 512 bytes.
ParseDomainError
The provided input could not be parsed because it is not a syntactically-valid DNS Domain.
ParseEncryptionAlgorithmError
An error type when parsing the encryption algorithm from str
SecretKeys
A collection of secret keys, you can just treat it as a Vec<SecretKey>.
SmolStr
A SmolStr is a string type that has the following properties:
SmolStrBuilder
A builder that can be used to efficiently build a SmolStr.
Tags
Tags of a node
TagsRef
The reference type to Tags, which is an iterator and yields a reference to the key and value

Enums

DelegateVersion
Delegate version
EncryptionAlgorithm
The encryption algorithm used to encrypt the message.
EncryptionError
Security errors
MaybeResolvedAddress
MaybeResolvedAddress is used to represent an address that may or may not be resolved.
MemberStatus
The member status.
MemberlistDelegateVersion
Delegate version
MemberlistProtocolVersion
Protocol version
ParseHostAddrError
An error which can be returned when parsing a HostAddr.
ParseNodeIdError
Errors that can occur when transforming an NodeId.
ParseSecretKeyError
Parse error for SecretKey from a base64 string
ProtocolVersion
Protocol version
SecretKey
The key used while attempting to encrypt/decrypt a message

Traits

Data
The memberlist data can be transmitted through the network.
DataRef
The reference type of the data.
StrExt
str methods producing SmolStrs.
ToSmolStr
Convert value to SmolStr using fmt::Display, potentially without allocating.

Type Aliases

Domainhostaddr
Domain type alias
HostAddrhostaddr
Host address type alias