pub struct LamportClock(/* private fields */);Expand description
A thread safe implementation of a lamport clock. It uses efficient atomic operations for all of its functions, falling back to a heavy lock only if there are enough CAS failures.
Implementations
Sourceimpl LamportClock
impl LamportClock
Sourcepub fn new() -> LamportClock
pub fn new() -> LamportClock
Creates a new lamport clock with the given initial value
Sourcepub fn time(&self) -> LamportTime
pub fn time(&self) -> LamportTime
Return the current value of the lamport clock
Sourcepub fn increment(&self) -> LamportTime
pub fn increment(&self) -> LamportTime
Increment and return the value of the lamport clock
Sourcepub fn witness(&self, time: LamportTime)
pub fn witness(&self, time: LamportTime)
Witness is called to update our local clock if necessary after witnessing a clock value received from another process