pub struct DnsResolver<R>where
R: Runtime,{ /* private fields */ }Available on crate features
resolver and dns only.Expand description
A resolver which supports both domain:port and socket address.
- If you can make sure, you always play with
SocketAddr, you may want to useSocketAddrResolver. - If you do not want to send DNS queries, you may want to use
AddressResolver.
N.B. If a domain contains multiple ip addresses, there is no guarantee that
which one will be used. Users should make sure that the domain only contains
one ip address, to make sure that DnsResolver can work properly.
e.g. valid address format:
www.example.com:8080// domain[::1]:8080// ipv6127.0.0.1:8080// ipv4