The types used in serf.
Modules
- bytes
- Provides abstractions for working with bytes.
- coordinate
- Vivialdi coordinate implementation
- utils
- Utils for protobuf-like encoding/decoding
Macros
- format_
smolstr - Formats arguments to a
SmolStr, potentially without allocating.
Structs
- Invalid
KeyLength - Parse error for
SecretKeyfrom bytes slice - KeyRequest
Message - KeyRequest is used to contain input parameters which get broadcasted to all nodes as part of a key query operation.
- KeyRequest
Options - KeyRequestOptions is used to contain optional parameters for a keyring operation
- KeyResponse
- KeyResponse is used to relay a query for a list of all keys in use.
- KeyResponse
Message - Key response message
- KeyResponse
Message Ref - The reference type for
KeyResponseMessage. - Lamport
Clock - A thread safe implementation of a lamport clock. It uses efficient atomic operations for all of its functions, falling back to a heavy lock only if there are enough CAS failures.
- Lamport
Time - A lamport time is a simple u64 that represents a point in time.
- Member
- A single member of the Serf cluster.
- Member
Ref - A reference type to
Member - Node
- Node is consist of id and address, which can be used as a identifier in a distributed system.
- NodeId
- A unique string identifying a server for all time. The maximum length of an id is 512 bytes.
- Parse
Domain Error - The provided input could not be parsed because it is not a syntactically-valid DNS Domain.
- Parse
Encryption Algorithm Error - An error type when parsing the encryption algorithm from str
- Secret
Keys - A collection of secret keys, you can just treat it as a
Vec<SecretKey>. - SmolStr
- A
SmolStris a string type that has the following properties: - Smol
StrBuilder - A builder that can be used to efficiently build a
SmolStr. - Tags
- Tags of a node
- TagsRef
- The reference type to
Tags, which is an iterator and yields a reference to the key and value
Enums
- Delegate
Version - Delegate version
- Encryption
Algorithm - The encryption algorithm used to encrypt the message.
- Encryption
Error - Security errors
- Maybe
Resolved Address MaybeResolvedAddressis used to represent an address that may or may not be resolved.- Member
Status - The member status.
- Memberlist
Delegate Version - Delegate version
- Memberlist
Protocol Version - Protocol version
- Parse
Host Addr Error - An error which can be returned when parsing a
HostAddr. - Parse
Node IdError - Errors that can occur when transforming an
NodeId. - Parse
Secret KeyError - Parse error for
SecretKeyfrom a base64 string - Protocol
Version - Protocol version
- Secret
Key - The key used while attempting to encrypt/decrypt a message
Traits
- Data
- The memberlist data can be transmitted through the network.
- DataRef
- The reference type of the data.
- StrExt
strmethods producingSmolStrs.- ToSmol
Str - Convert value to
SmolStrusingfmt::Display, potentially without allocating.